pub struct Server { /* private fields */ }Expand description
A running iroh-dns server.
Combines a DNS listener and an HTTP/HTTPS listener into a single handle.
Construct with Self::bind and drive to completion with Self::join, or
stop the tasks with Self::shutdown.
Implementations
Sourceimpl Server
impl Server
Sourcepub async fn bind(config: Config) -> Result<Self>
pub async fn bind(config: Config) -> Result<Self>
Binds and spawns the server from a Config.
Opens the persistent signed-packet store, enables the mainline DHT fallback when configured, and spawns the DNS, HTTP(S), and metrics tasks. Returns once all listeners are bound.
Sourcepub async fn shutdown(self) -> Result<()>
pub async fn shutdown(self) -> Result<()>
Cancels the server tasks and waits for them to complete.
Sourcepub async fn join(self) -> Result<()>
pub async fn join(self) -> Result<()>
Waits for the server tasks to complete.
Returns when a listener task finishes, either with success or an error.
Sourcepub fn dns_addr(&self) -> SocketAddr
pub fn dns_addr(&self) -> SocketAddr
Returns the local address that the DNS listener is bound to.
Sourcepub fn http_addr(&self) -> Option<SocketAddr>
pub fn http_addr(&self) -> Option<SocketAddr>
Returns the local address of the HTTP listener, or None if no HTTP
listener was configured.
Sourcepub fn https_addr(&self) -> Option<SocketAddr>
pub fn https_addr(&self) -> Option<SocketAddr>
Returns the local address of the HTTPS listener, or None if no HTTPS
listener was configured.